<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>EditShare</name>
    <message>
        <location filename="../editshare.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалоговое окно</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="20"/>
        <source>&amp;Name</source>
        <translation>&amp;Имя</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="30"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="37"/>
        <source>&amp;Path</source>
        <translation>&amp;Путь</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="51"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="56"/>
        <source>No</source>
        <translation>Нет</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="64"/>
        <source>&amp;Comment</source>
        <translation>&amp;Комментарий</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="77"/>
        <source>&amp;Guest OK</source>
        <translation>&amp;Гостевой доступ</translation>
    </message>
    <message>
        <location filename="../editshare.ui" line="111"/>
        <source>Access rights for valid users</source>
        <translation>Права доступа для существующих пользователей</translation>
    </message>
    <message>
        <location filename="../editshare.cpp" line="46"/>
        <source>Select directory to share</source>
        <translation>Выберите каталог для общего доступа</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="24"/>
        <source>&amp;Shares</source>
        <translation>&amp;Общие ресурсы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <source>Shares</source>
        <translation>Общие ресурсы</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="41"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba user shares found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Не найдено пользовательских ресурсов samba&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="50"/>
        <location filename="../mainwindow.ui" line="157"/>
        <source>&amp;Remove</source>
        <translation>&amp;Удалить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="63"/>
        <location filename="../mainwindow.ui" line="164"/>
        <source>&amp;Add</source>
        <translation>&amp;Добавить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="70"/>
        <source>&amp;Edit</source>
        <translation>&amp;Изменить</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="80"/>
        <source>Name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="85"/>
        <source>Path</source>
        <translation>Путь</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="90"/>
        <source>Comment</source>
        <translation>Комментарий</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>Permissions</source>
        <translation>Разрешения</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="100"/>
        <source>Guest OK</source>
        <translation>Гостевой доступ</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="142"/>
        <source>&amp;Users</source>
        <translation>&amp;Пользователи</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="150"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;No samba users found&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-weight:600;&quot;&gt;Не найдено пользователей Samba&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="171"/>
        <source>&amp;Password</source>
        <translation>&amp;Пароль</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Users</source>
        <translation>Пользователи</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="219"/>
        <location filename="../mainwindow.cpp" line="311"/>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>E&amp;nable Automatic Samba Startup</source>
        <translation>&amp;Автоматически запускать Samba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="226"/>
        <location filename="../mainwindow.cpp" line="288"/>
        <location filename="../mainwindow.cpp" line="346"/>
        <source>Star&amp;t Samba</source>
        <translation>&amp;Запуск Samba</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="254"/>
        <source>Samba autostart service is disabled</source>
        <translation>Автозапуск Samba отключен</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="285"/>
        <location filename="../mainwindow.cpp" line="286"/>
        <source>Samba is running</source>
        <translation>Samba запущена</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="324"/>
        <source>About this application</source>
        <translation>Об этом приложении</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="327"/>
        <source>A&amp;bout...</source>
        <translation>О п&amp;рограмме...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="334"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="366"/>
        <source>Display help </source>
        <translation>Показать справку</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="369"/>
        <source>&amp;Help</source>
        <translation>&amp;Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="376"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Выход</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>&amp;Close</source>
        <translation>&amp;Закрыть</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <location filename="../mainwindow.cpp" line="98"/>
        <location filename="../mainwindow.cpp" line="127"/>
        <location filename="../mainwindow.cpp" line="139"/>
        <location filename="../mainwindow.cpp" line="209"/>
        <location filename="../mainwindow.cpp" line="274"/>
        <location filename="../mainwindow.cpp" line="292"/>
        <location filename="../mainwindow.cpp" line="385"/>
        <location filename="../mainwindow.cpp" line="412"/>
        <location filename="../mainwindow.cpp" line="416"/>
        <location filename="../mainwindow.cpp" line="422"/>
        <location filename="../mainwindow.cpp" line="428"/>
        <location filename="../mainwindow.cpp" line="458"/>
        <location filename="../mainwindow.cpp" line="464"/>
        <location filename="../mainwindow.cpp" line="478"/>
        <location filename="../mainwindow.cpp" line="488"/>
        <location filename="../mainwindow.cpp" line="511"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <location filename="../mainwindow.cpp" line="540"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="94"/>
        <source>Error, could not add share. Empty share name</source>
        <translation>Ошибка добавления ресурса. Пустое имя ресурса.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="99"/>
        <source>Path: %1 doesn&apos;t exist.</source>
        <translation>Путь %1 не существует.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="124"/>
        <source>Yes</source>
        <translation>Да</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="128"/>
        <source>Could not add share. Error message:

%1</source>
        <translation>Не удалось добавить общий ресурс. Сообщение об ошибке:

%1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="139"/>
        <source>Error listing users</source>
        <translation>Ошибка получения списка пользователей</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <source>&amp;Deny</source>
        <translation>&amp;Запретить</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="175"/>
        <source>&amp;Read Only</source>
        <translation>&amp;Только чтение</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="185"/>
        <source>&amp;Full Access</source>
        <translation>&amp;Полный доступ</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="209"/>
        <source>Error listing shares</source>
        <translation>Ошибка получения списка общих ресурсов</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="275"/>
        <source>Your user doesn&apos;t belong to &apos;sambashare&apos; group  if you just installed the app you might need to restart the system first.</source>
        <translation>Пользователь не входит в группу sambashare. Если приложение было только   что установлено, заново войдите в систему.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="285"/>
        <source>Sto&amp;p Samba</source>
        <translation>О&amp;становить Samba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="289"/>
        <source>Samba is not running</source>
        <translation>Samba не запущена</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="292"/>
        <source>Samba not installed</source>
        <translation>Samba не установлена</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="308"/>
        <source>&amp;Disable Automatic Samba Startup</source>
        <translation>Отклю&amp;чить автозапуск Samba</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>About %1</source>
        <translation>О %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <source>MX Samba Config</source>
        <translation>Настройка Samba в MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="361"/>
        <source>Version: </source>
        <translation>Версия: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>Program for configuring Samba shares and users.</source>
        <translation>Программа для настройки общих ресурсов и пользователей Samba.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="366"/>
        <source>%1 License</source>
        <translation>%1 Лицензия</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="373"/>
        <source>%1 Help</source>
        <translation>%1 Справка</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="385"/>
        <source>Cannot delete user: </source>
        <translation>Не удалось удалить пользователя:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Enter the username and password:</source>
        <translation>Введите имя пользователя и пароль:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="400"/>
        <source>Username:</source>
        <translation>Пользователь:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="401"/>
        <location filename="../mainwindow.cpp" line="447"/>
        <source>Password:</source>
        <translation>Пароль:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="402"/>
        <location filename="../mainwindow.cpp" line="448"/>
        <source>Confirm password:</source>
        <translation>Подтверждение пароля:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="412"/>
        <source>Empty username, please enter a name.</source>
        <translation>Пустое имя пользователя, пожалуйста, укажите его.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="417"/>
        <source>Matching linux user not found on system, make sure you enter a valid username.</source>
        <translation>Соответствующий пользователь linux не найден в системе; проверьте имя пользователя.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="422"/>
        <location filename="../mainwindow.cpp" line="458"/>
        <source>Passwords don&apos;t match, please enter again.</source>
        <translation>Пароли не совпадают; введите их заново.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="428"/>
        <source>Could not add user.</source>
        <translation>Не удалось добавить пользователя.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="441"/>
        <source>Change the password for &apos;%1&apos;</source>
        <translation>Смена пароля «%1»</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="464"/>
        <source>Could not change password.</source>
        <translation>Не удалось сменить пароль.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="478"/>
        <source>Cannot delete share: </source>
        <translation>Не удаль удалить общий ресурс:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="489"/>
        <location filename="../mainwindow.cpp" line="541"/>
        <source>Samba service is not running. Please start Samba before adding or editing shares</source>
        <translation>Служба Samba не запущена. Запустите Samba перед работой с общими ресурсами</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="511"/>
        <location filename="../mainwindow.cpp" line="528"/>
        <source>Error: trying to process permissions: </source>
        <translation>Ошибка при обработке разрешений:</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="42"/>
        <source>License</source>
        <translation>Лицензия</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="43"/>
        <location filename="../about.cpp" line="52"/>
        <source>Changelog</source>
        <translation>Список изменений</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="44"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="64"/>
        <source>&amp;Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="61"/>
        <source>You must run this program as normal user.</source>
        <translation>Вы должны запустить эту программу как обычный пользователь.</translation>
    </message>
</context>
</TS>
